#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.trigger_dagrun import TriggerDagRunOperator
from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_smart_ccc_custom', default_args=default_args,
schedule_interval="0 0-23/1 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="smart_ccc_custom_failed",
    html_content='<h3>您好，smart_ccc_custom作业失败，请及时处理" </h3>')

customer_list_feign = SSHOperator(
ssh_hook=sshHook,
task_id='customer_list_feign',
command='python3 /data/airflow/etl/API/customer_list_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

customer_list_load = SSHOperator(
ssh_hook=sshHook,
task_id='customer_list_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"customer_list_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_list_feign >> customer_list_load

customer_labels_feign = SSHOperator(
ssh_hook=sshHook,
task_id='customer_labels_feign',
command='python3 /data/airflow/etl/API/customer_labels_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

customer_labels_load = SSHOperator(
ssh_hook=sshHook,
task_id='customer_labels_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"customer_labels_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_labels_feign >> customer_labels_load

tr_custom_details_5516 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_custom_details_5516',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_custom_details"},
depends_on_past=False, 
retries=3, 
dag=dag)

tr_custom_labels_8280 = SSHOperator(
ssh_hook=sshHook,
task_id='tr_custom_labels_8280',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_tr_custom_labels"},
depends_on_past=False, 
retries=3, 
dag=dag)

t01_ccc_cust_label = SSHOperator(
ssh_hook=sshHook,
task_id='t01_ccc_cust_label',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_ccc_cust_label_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
t01_ccc_cust_info = SSHOperator(
ssh_hook=sshHook,
task_id='t01_ccc_cust_info',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_ccc_cust_info_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)

dysql_ccc_scrm_cust_label_info = SSHOperator(
ssh_hook=sshHook,
task_id='dysql_ccc_scrm_cust_label_info',
command='/data/airflow/etl/MART/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"dysql_ccc_scrm_cust_label_info"},
depends_on_past=False, 
retries=3, 
dag=dag)



huiju_tags_feign = SSHOperator(
ssh_hook=sshHook,
task_id='huiju_tags_feign',
command='python3 /data/airflow/etl/API/huiju_tags_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

huiju_tags_load = SSHOperator(
ssh_hook=sshHook,
task_id='huiju_tags_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"huiju_tags_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

huiju_tags_feign >> huiju_tags_load

scrm_tags_5000 = SSHOperator(
ssh_hook=sshHook,
task_id='scrm_tags_5000',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_scrm_tags"},
depends_on_past=False, 
retries=3, 
dag=dag)


uds_crm_tag_update = SSHOperator(
ssh_hook=sshHook,
task_id='uds_crm_tag_update',
command='python /data/airflow/etl/Python/crm_tag_update.py',
params={'my_param':"uds_crm_tag_update"},
depends_on_past=False, 
retries=3, 
dag=dag)

t01_scrm_label = SSHOperator(
ssh_hook=sshHook,
task_id='t01_scrm_label',
command='/data/airflow/etl/PDM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_scrm_label_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
cust_label_rela = SSHOperator(
ssh_hook=sshHook,
task_id='cust_label_rela',
command='/data/airflow/etl/COM/run_psql.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"cust_label_rela_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
customer_labels_load >> tr_custom_labels_8280
customer_list_load >> tr_custom_details_5516
tr_custom_labels_8280 >> t01_ccc_cust_label
tr_custom_details_5516 >> t01_ccc_cust_info
t01_ccc_cust_label >> dysql_ccc_scrm_cust_label_info
t01_ccc_cust_info >> dysql_ccc_scrm_cust_label_info
huiju_tags_load >> scrm_tags_5000
dysql_ccc_scrm_cust_label_info >> uds_crm_tag_update
t01_scrm_label >> cust_label_rela
scrm_tags_5000 >> t01_scrm_label
cust_label_rela >> uds_crm_tag_update
cust_label_rela >> dysql_ccc_scrm_cust_label_info
dysql_ccc_scrm_cust_label_info >> task_failed 
